<?php

namespace Drupal\revision_menu_trail;

use Drupal\Core\Menu\MenuActiveTrail;
use Drupal\Core\Url;

/**
 * Extend menu active trail to look for the current revision.
 */
class RevisionMenuTrail extends MenuActiveTrail {

  public const REGEX_APPLICABLE_ROUTE_NAMES = '/^entity\.([^.]+).(revision|latest_version)$/';

  /**
   * {@inheritdoc}
   */
  public function getActiveLink($menu_name = NULL) {
    $route_name = $this->routeMatch->getRouteName();

    // On a default (not custom) 403 page the route name is NULL.
    if (!$route_name) {
      return NULL;
    }

    if (!preg_match(self::REGEX_APPLICABLE_ROUTE_NAMES, $route_name, $matches)) {
      // Use the default behavior if this is not a revision route or the latest
      // revision route from content_moderation.
      return parent::getActiveLink($menu_name);
    }

    /** @var \Drupal\Core\Entity\EntityInterface $entity */
    $entity = $this->routeMatch->getParameter($matches[1]);
    // The URL object returned by $entity->toUrl() is created from the
    // definition provided by the entity and may not contain all the route
    // parameters required to match links. E.g. for taxonomy routes if views has
    // overridden the route there are additional parameters which are can be
    // found using the route match service when constructing a new URL.
    $entity_path = substr($entity->toUrl('canonical')->toString(), strlen(base_path()));
    $entity_url = Url::fromUserInput('/' . $entity_path);

    // Load links matching this route.
    $links = $this->menuLinkManager->loadLinksByRoute($entity_url->getRouteName(), $entity_url->getRouteParameters(), $menu_name);
    // Select the first matching link.
    if ($links) {
      return reset($links);
    }

    return NULL;

  }

}
