<?php

namespace Drupal\Tests\revision_menu_trail\Unit;

use Drupal\revision_menu_trail\RevisionMenuTrail;
use Drupal\Tests\UnitTestCase;

/**
 * Tests that the regex matches expected paths.
 *
 * @group revision_menu_trail
 */
class RouteNameRegexTest extends UnitTestCase {

  /**
   * Test the regex matches expected routes.
   *
   * @dataProvider dataProviderApplicableRoutes
   */
  public function testApplicableRoutes($routeName) {
    $this->assertEquals(1, preg_match(RevisionMenuTrail::REGEX_APPLICABLE_ROUTE_NAMES, $routeName));
  }

  /**
   * Test the regex does not match to unexpected routes.
   *
   * @dataProvider dataProviderInapplicableRoutes
   */
  public function testInapplicableRoutes($routeName) {
    $this->assertEquals(0, preg_match(RevisionMenuTrail::REGEX_APPLICABLE_ROUTE_NAMES, $routeName));
  }

  /**
   * Provides test data for testApplicableRoutes().
   */
  public static function dataProviderApplicableRoutes(): array {
    return [
      ['entity.node.latest_version'],
      ['entity.node.revision'],
      ['entity.taxonomy_term.latest_version'],
      ['entity.taxonomy_term.revision'],
      ['entity.your_custom_entity_type.latest_version'],
      ['entity.your_custom_entity_type.revision'],
    ];
  }

  /**
   * Provides test data for testApplicableRoutes().
   */
  public static function dataProviderInapplicableRoutes(): array {
    return [
      ['entity.node.canonical'],
      ['entity.node.revert_revision'],
      ['big_pipe.nojs'],
      ['entity.block.delete_form'],
      ['block.category_autocomplete'],
      ['custom.node.revision'],
    ];
  }

}
